package com.mint.mintdemo;

import static com.mint.mintdemo.Constants.*;
import static com.mint.mintdemo.Util.printLogV;

import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.text.SpannableStringBuilder;
import android.text.Spanned;
import android.text.style.ForegroundColorSpan;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;
import androidx.preference.PreferenceManager;

import com.mint.mintdemo.advanced.native_in_recycler.NativeAdInRecyclerViewActivity;
import com.mint.mintdemo.advanced.native_in_view_pager.NativeAdInViewPager2Activity;
import com.mint.mintdemo.basic.BasicBannerActivity;
import com.mint.mintdemo.basic.BasicInterstitialActivity;
import com.mint.mintdemo.basic.BasicNativeActivity;
import com.mint.mintdemo.basic.BasicRewardedInterstitialActivity;
import com.mint.mintdemo.basic.BasicRewardedVideoActivity;
import com.mint.mintdemo.basic.BasicSplashActivity;
import com.yandex.mobile.ads.common.MobileAds;
import com.zeus.gmc.sdk.mobileads.mintmediation.InitCallback;
import com.zeus.gmc.sdk.mobileads.mintmediation.InitOptions;
import com.zeus.gmc.sdk.mobileads.mintmediation.MintAds;
import com.zeus.gmc.sdk.mobileads.mintmediation.impression.ImpressionData;
import com.zeus.gmc.sdk.mobileads.mintmediation.impression.ImpressionDataListener;
import com.zeus.gmc.sdk.mobileads.mintmediation.testsuite.TestSuite;
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.error.Error;

import java.util.ArrayList;
import java.util.List;

public class MainActivity extends AppCompatActivity {

    private TextView mTvInitState;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_main);

        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(this);
        if (sp.getBoolean(KEY_FIRST_OPEN, true)) {
            sp.edit()
                    .putString(KEY_MINT_APP_KEY, MINT_APP_KEY)
                    .putBoolean(KEY_FIRST_OPEN, false)
                    .putString(KEY_COPPA, "Not Set")
                    .putString(KEY_CCPA, "Not Set")
                    .apply();
        }
        ActionBar supportBar = getSupportActionBar();
        if (supportBar != null) {
            supportBar.setDisplayShowTitleEnabled(false);
            supportBar.setDisplayUseLogoEnabled(true);
            supportBar.setDisplayShowHomeEnabled(true);
            supportBar.setLogo(R.drawable.mint_logo);
        }

        boolean preloadInterstitial = sp.getBoolean(KEY_PRELOAD_INTERSTITIAL, true);
        boolean preloadRewardedVideo = sp.getBoolean(KEY_PRELOAD_REWARDED_VIDEO, true);
        boolean preloadRewardedInterstitial = sp.getBoolean(KEY_PRELOAD_REWARDED_INTERSTITIAL, false);
        String appKey = sp.getString(KEY_MINT_APP_KEY, MINT_APP_KEY);
        boolean gdprConsent = sp.getBoolean(KEY_GDPR, false);
        String ccpa = sp.getString(KEY_CCPA, "Not Set");
        String coppa = sp.getString(KEY_COPPA, "Not Set");
        boolean userExperience = sp.getBoolean(KEY_USER_EXPERIENCE, false);
        int age = sp.getInt(KEY_AGE, -1);
        String gender = sp.getString(KEY_GENDER, null);


        mTvInitState = findViewById(R.id.tv_init_state);
        setHeaderText(findViewById(R.id.tv_version), "SDK VERSION:", MintAds.getSDKVersion());

        // CCPA, USPrivacy Limit
        if ("Limited".equals(ccpa)) {
            MintAds.setUSPrivacyLimit(true);
        } else if ("Not Limit".equals(ccpa)) {
            MintAds.setUSPrivacyLimit(false);
        }
        // User age restricted
        if ("Limited".equals(coppa)) {
            MintAds.setAgeRestricted(true);
        } else if ("Not Limit".equals(coppa)) {
            MintAds.setAgeRestricted(false);
        }
        // User experience on
        MintAds.setUserExperienceOn(userExperience);

        if ("Male".equals(gender)) {
            MintAds.setUserGender("male");
        } else if ("Female".equals(gender)) {
            MintAds.setUserGender("female");
        }
        if (-1 != age) {
            MintAds.setUserAge(age);
        }
        MintAds.setDebugEnable(true);
        MintAds.setCustomDeviceId("YOUR CUSTOM DEVICE ID");

        // yandex test mode, for yandex only
        MobileAds.enableLogging(true);
        MobileAds.enableDebugErrorIndicator(true);

        // set ad impression data listener, this will callback ad impress result, optional
        MintAds.setImpressionDataListener(new ImpressionDataListener() {
            @Override
            public void onImpressionSuccess(ImpressionData impressionData) {
                printLogV("Ad impression result: " + impressionData);
                // ad type, Banner\Native\Splash\Interstitial\RewardedVideo\RewardedInterstitial
                String adType = impressionData.getAdType();
                // ISO 4217 currency code, e.g. USD, CNY, JPY, etc.
                String cur = impressionData.getCurrency();
                // country name, such as cn, us, jp, etc.
                String country = impressionData.getCountry();
                // ad network name, such as AdMob, Facebook, Unity, Vungle, etc.
                String mediation = impressionData.getMediationId();
                // Mint Mediation placement id
                String placementId = impressionData.getPlacementId();
                // impression revenue
                double revenue = impressionData.getRevenue();
            }
        });

        // Before SDK init, you must set GDPR consent value
        MintAds.setGDPRConsent(gdprConsent);

        // SDK Init
        List<MintAds.PRELOAD_AD_TYPE> preloadAdTypeList = new ArrayList<>();
        if (preloadInterstitial) {
            preloadAdTypeList.add(MintAds.PRELOAD_AD_TYPE.INTERSTITIAL);
        }
        if (preloadRewardedVideo) {
            preloadAdTypeList.add(MintAds.PRELOAD_AD_TYPE.REWARDED_VIDEO);
        }
        if (preloadRewardedInterstitial) {
            preloadAdTypeList.add(MintAds.PRELOAD_AD_TYPE.REWARDED_INTERSTITIAL);
        }
        if (preloadAdTypeList.isEmpty()) {
            preloadAdTypeList.add(MintAds.PRELOAD_AD_TYPE.NONE);
        }
        InitOptions mintInitOptions = new InitOptions.Builder()
                .appKey(appKey)
                .preloadAdTypes(preloadAdTypeList.toArray(new MintAds.PRELOAD_AD_TYPE[0]))
                .channel("YOUR APP CHANNEL")
                .build();

        setHeaderText(mTvInitState, "INIT STATE:", "Loading...");
        printLogV("Init with ppkey:" + appKey);

        MintAds.init(mintInitOptions, new InitCallback() {
            @Override
            public void onSuccess() {

                // Set IAP after sdk init
                MintAds.setIAP(5.0f, "USD");

                setHeaderText(mTvInitState, "INIT STATE:", "success");
            }

            @Override
            public void onError(Error error) {
                setHeaderText(mTvInitState, "INIT STATE:", "error");
            }
        });
    }

    private void setHeaderText(TextView tv, String title, String message) {
        String str = title + " " + message;
        SpannableStringBuilder ssb = new SpannableStringBuilder(str);
        ssb.setSpan(new ForegroundColorSpan(0x70ffffff), title.length(), str.length(),
                Spanned.SPAN_EXCLUSIVE_EXCLUSIVE);
        tv.setText(ssb);
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        if (R.id.action_setting == item.getItemId()) {
            startActivity(new Intent(this, SettingsActivity.class));
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    public void onBasicBannerClick(View v) {
        startActivity(new Intent(this, BasicBannerActivity.class));
    }

    public void onBasicNativeClick(View v) {
        startActivity(new Intent(this, BasicNativeActivity.class));
    }

    public void onBasicSplashClick(View v) {
        startActivity(new Intent(this, BasicSplashActivity.class));
    }

    public void onBasicInterstitialClick(View v) {
        startActivity(new Intent(this, BasicInterstitialActivity.class));
    }

    public void onBasicRewardedVideoClick(View v) {
        startActivity(new Intent(this, BasicRewardedVideoActivity.class));
    }

    public void onBasicRewardedInterstitialClick(View view) {
        startActivity(new Intent(this, BasicRewardedInterstitialActivity.class));
    }

    public void onNativeRecyclerClick(View v) {
        startActivity(new Intent(this, NativeAdInRecyclerViewActivity.class));
    }

    public void onNativeViewPagerClick(View v) {
        startActivity(new Intent(this, NativeAdInViewPager2Activity.class));
    }


    public void onTestSuiteClick(View view) {
        SharedPreferences sp = PreferenceManager.getDefaultSharedPreferences(this);
        String appKey = sp.getString(KEY_MINT_APP_KEY, MINT_APP_KEY);
        TestSuite.open(this, appKey);
    }
}
