package com.mint.mintdemo.advanced.native_in_recycler;

import static com.mint.mintdemo.Constants.NATIVE_PLACEMENT_ID;
import static com.mint.mintdemo.Util.appendInfo;

import android.os.Bundle;
import android.text.method.ScrollingMovementMethod;
import android.view.MenuItem;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout;

import com.mint.mintdemo.R;
import com.mint.mintdemo.Util;
import com.mint.mintdemo.utils.pull_to_refresh.PullToRefreshViewController;

import java.util.List;

public class NativeAdInRecyclerViewActivity extends AppCompatActivity implements
        SwipeRefreshLayout.OnRefreshListener, PullToRefreshViewController<Object> {

    private final NativeAdRecyclerAdapter mAdapter = new NativeAdRecyclerAdapter(
            NativeAdRecyclerAdapter.TYPE_LIST);
    private NativeAdPageDataLoader mDataLoader;

    private TextView mTvInfo;
    private RecyclerView mRecyclerView;
    private SwipeRefreshLayout mRefreshLayout;
    private ProgressBar mPbLoadMore;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_native_ad_in_recycler_view);

        ActionBar actionBar = getSupportActionBar();
        if (actionBar != null) {
            actionBar.setDisplayHomeAsUpEnabled(true);
            actionBar.setTitle(R.string.native_in_recycler_view);
        }

        mTvInfo = findViewById(R.id.tv_info);
        mRecyclerView = findViewById(R.id.rv);
        mRefreshLayout = findViewById(R.id.srl);
        mPbLoadMore = findViewById(R.id.pb_load_more);

        mTvInfo.setMovementMethod(new ScrollingMovementMethod());
        mRecyclerView.setLayoutManager(new LinearLayoutManager(this));
        mRecyclerView.setAdapter(mAdapter);

        mRecyclerView.addOnScrollListener(new RecyclerView.OnScrollListener() {
            @Override
            public void onScrollStateChanged(@NonNull RecyclerView recyclerView, int newState) {
                if (mAdapter.mData == null || mAdapter.mData.isEmpty()) {
                    return;
                }
                if (!recyclerView.canScrollVertically(1) &&
                        RecyclerView.SCROLL_STATE_IDLE == newState) {
                    // recycler view scroll to bottom
                    onLoadMore();
                }
            }
        });

        mDataLoader = new NativeAdPageDataLoader(this,
                20, 20, new Util.Logger() {
            @Override
            public void printMsg(String msg) {
                appendInfo(mTvInfo, msg);
            }
        });

        appendInfo(mTvInfo, "Placement ID: " + NATIVE_PLACEMENT_ID);

        mRefreshLayout.setRefreshing(true);
        onRefresh();
    }

    @Override
    public void onRefresh() {
        if (!mDataLoader.onRefresh(this)) {
            mRefreshLayout.setRefreshing(false);
        }
    }


    private void onLoadMore() {
        if (mDataLoader.onLoadMore(this)) {
            mRefreshLayout.setEnabled(false);
            mPbLoadMore.setVisibility(View.VISIBLE);
        }
    }

    @Override
    public void onRefreshFinish(List<Object> data) {
        mRefreshLayout.setRefreshing(false);
        mAdapter.onDataRefreshed(data);
    }

    @Override
    public void onLoadMoreFinish(List<Object> data) {
        mRefreshLayout.setEnabled(false);
        mPbLoadMore.setVisibility(View.INVISIBLE);
        mAdapter.onDataAppend(data);
    }


    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        if (android.R.id.home == item.getItemId()) {
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    protected void onDestroy() {
        mDataLoader.onDestroy();
        super.onDestroy();

    }

}
