package com.mint.mintdemo.advanced.native_in_recycler;

import static com.mint.mintdemo.Constants.NATIVE_PLACEMENT_ID;

import android.app.Activity;
import android.os.Handler;
import android.os.Looper;
import android.util.DisplayMetrics;
import android.view.LayoutInflater;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.RelativeLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;

import com.mint.mintdemo.R;
import com.mint.mintdemo.Util;
import com.mint.mintdemo.utils.pull_to_refresh.BasePullToRefreshDataLoader;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.AdIconView;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.MediaView;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.NativeAd;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.NativeAdListener;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.NativeAdLoader;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.NativeAdView;

import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;

public class NativeAdPageDataLoader extends BasePullToRefreshDataLoader<Object> implements NativeAdListener {
    private final int mPageSize;
    private final int mNativeAdGap;
    private final Util.Logger mLogger;
    private final NativeAdLoader mAdLoader;

    private final List<NativeAdDataHolder> mAvailableNativeAdPool = new LinkedList<>();
    private final List<NativeAdDataHolder> mRenderedNativeAdPool = new LinkedList<>();

    public NativeAdPageDataLoader(Activity activity, int pageSize, int nativeAdGap,
                                  Util.Logger logger) {
        this.mPageSize = pageSize;
        this.mNativeAdGap = nativeAdGap;
        this.mLogger = logger;
        this.mAdLoader = new NativeAdLoader(activity, NATIVE_PLACEMENT_ID, this);
    }

    @Override
    protected void loadData(int pageNo, PageDataCallback<Object> callback) {
        int pageAdCount = mPageSize / mNativeAdGap;
        mAdLoader.loadAd();
        new Handler(Looper.getMainLooper()).postDelayed(new Runnable() {
            @Override
            public void run() {
                int totalDataCount = mPageSize + pageAdCount;
                List<Object> result = new ArrayList<>(totalDataCount);

                for (int i = 0; i < mPageSize; i++) {
                    int realIndex = ((pageNo - 1) * mPageSize) + i;
                    result.add("Item index " + realIndex);
                    if ((realIndex % mNativeAdGap) == 0) {
                        // ad position, insert ad
                        NativeAd ad = mAdLoader.getNativeAd();
                        if (ad == null) {
                            mAdLoader.loadAd();
                        } else {
                            mLogger.printMsg("Insert Ad after " + realIndex);
                            NativeAdDataHolder holder = new NativeAdDataHolder(ad);
                            mAvailableNativeAdPool.add(holder);
                            result.add(holder);
                        }
                    }
                }

                if (pageNo == 1) {
                    // remove rendered ad
                    clearRenderedAd();
                }

                callback.onDataLoad(result);
            }
        }, 3000);
    }

    private void clearRenderedAd() {
        for (NativeAdDataHolder h : mRenderedNativeAdPool) {
            h.mNativeAd.destroy();
        }
        mRenderedNativeAdPool.clear();
    }


    void onDestroy() {
        for (NativeAdDataHolder h : mAvailableNativeAdPool) {
            h.mNativeAd.destroy();
        }
        mAvailableNativeAdPool.clear();
        for (NativeAdDataHolder h : mRenderedNativeAdPool) {
            h.mNativeAd.destroy();
        }
        mRenderedNativeAdPool.clear();
        mAdLoader.destroy();
    }


    private void onAdRendered(NativeAdDataHolder holder) {
        mRenderedNativeAdPool.add(holder);
        mAvailableNativeAdPool.remove(holder);
    }

    @Override
    public void onAdReady() {

    }

    @Override
    public void onAdFailed(String s) {

    }

    @Override
    public void onAdClicked() {

    }

    class NativeAdDataHolder {
        private final NativeAd mNativeAd;
        private AdRender mAdRender;

        NativeAdDataHolder(@NonNull NativeAd nativeAd) {
            this.mNativeAd = nativeAd;
        }

        void showAd(FrameLayout container) {
            if (mAdRender == null) {
                mAdRender = new AdRender();
            }
            mAdRender.render(container, mNativeAd);
            onAdRendered(this);
        }
    }

    static class AdRender {

        private NativeAdView cachedAdView;

        void render(FrameLayout container,
                    NativeAd adInfo) {
            if (cachedAdView == null) {
                NativeAdView mintAdView = new NativeAdView(container.getContext());
                RelativeLayout simpleAdView = (RelativeLayout) LayoutInflater.from(
                        container.getContext()).inflate(R.layout.simple_native_layout, mintAdView,
                        false);
                TextView tvTitle = simpleAdView.findViewById(R.id.tv_title);
                TextView tvDesc = simpleAdView.findViewById(R.id.tv_desc);
                Button btnCta = simpleAdView.findViewById(R.id.btn_cta);
                AdIconView iconView = simpleAdView.findViewById(R.id.mint_icon_view);
                MediaView mediaView = simpleAdView.findViewById(R.id.mint_media_view);
                TextView advertiser = simpleAdView.findViewById(R.id.tv_ad);

                mintAdView.addView(simpleAdView);
                mintAdView.setTitleView(tvTitle);
                mintAdView.setDescView(tvDesc);
                mintAdView.setAdIconView(iconView);
                mintAdView.setCallToActionView(btnCta);
                mintAdView.setMediaView(mediaView);
                mintAdView.setAdvertiserView(advertiser);

                // only for yandex
                TextView domainView = simpleAdView.findViewById(R.id.ad_yandex_domain_view);
                TextView priceView = simpleAdView.findViewById(R.id.ad_yandex_price_view);
                TextView sponsoredView = simpleAdView.findViewById(R.id.ad_yandex_sponsored_view);
                TextView warningView = simpleAdView.findViewById(R.id.ad_yandex_warning_view);
                ImageView feedbackView = simpleAdView.findViewById(R.id.ad_yandex_feedback_view);
                mintAdView.setDomainView(domainView);
                mintAdView.setPriceView(priceView);
                mintAdView.setSponsoredView(sponsoredView);
                mintAdView.setWarningView(warningView);
                mintAdView.setFeedbackView(feedbackView);

                DisplayMetrics displayMetrics = container.getContext().getResources().getDisplayMetrics();
                mediaView.getLayoutParams().height = (int)(displayMetrics.widthPixels / (1200.0 / 627.0));
                mediaView.setImageScaleType(ImageView.ScaleType.CENTER_INSIDE);
                FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(
                        FrameLayout.LayoutParams.MATCH_PARENT,
                        FrameLayout.LayoutParams.WRAP_CONTENT);

                tvTitle.setText(adInfo.getTitle());
                tvDesc.setText(adInfo.getDesc());
                btnCta.setText(adInfo.getCallToActionText());
                adInfo.registerNativeAdView(mintAdView);

                container.removeAllViews();
                container.addView(mintAdView, layoutParams);

                cachedAdView = mintAdView;
            } else {
                container.removeAllViews();
                container.addView(cachedAdView);
            }
        }
    }

}
