package com.mint.mintdemo.advanced.native_in_recycler;

import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.RecyclerView;

import com.mint.mintdemo.R;

import java.util.List;

public class NativeAdRecyclerAdapter extends RecyclerView.Adapter<RecyclerView.ViewHolder> {

    public static final int TYPE_LIST = 1;
    public static final int TYPE_PAGER = 2;

    private final int type;

    private int typeData = 1;
    private int typeAd = 2;

    public List<Object> mData;

    public NativeAdRecyclerAdapter(int type) {
        this.type = type;
    }

    public void onDataRefreshed(List<Object> data) {
        mData = data;
        notifyDataSetChanged();
    }

    public void onDataAppend(List<Object> data) {
        if (mData != null) {
            int startIndex = mData.size();
            mData = data;
            notifyItemRangeInserted(startIndex, data.size());
        } else {
            mData = data;
            notifyDataSetChanged();
        }
    }


    @NonNull
    @Override
    public RecyclerView.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {
        if (viewType == typeData) {
            if (type == TYPE_PAGER) {
                return new DataViewHolder(LayoutInflater.from(parent.getContext()).inflate(
                        R.layout.item_pager_data, parent, false));
            } else {
                return new DataViewHolder(LayoutInflater.from(parent.getContext()).inflate(
                        android.R.layout.simple_list_item_1, parent, false));
            }
        } else {
            if (type == TYPE_PAGER) {
                return new AdViewHolder(LayoutInflater.from(parent.getContext()).inflate(
                        R.layout.item_pager_ad, parent, false));
            } else {
                return new AdViewHolder(new FrameLayout(parent.getContext()));
            }
        }
    }

    @Override
    public void onBindViewHolder(@NonNull RecyclerView.ViewHolder holder, int position) {
        int type = getItemViewType(position);
        if (typeData == type) {
            ((DataViewHolder) holder).tvTitle.setText(mData.get(position).toString());
        } else {
            // show ad
            NativeAdPageDataLoader.NativeAdDataHolder adInfoHolder =
                    ((NativeAdPageDataLoader.NativeAdDataHolder) mData.get(position));
            ((AdViewHolder) holder).showAd(adInfoHolder);
        }
    }

    @Override
    public int getItemCount() {
        return mData == null ? 0 : mData.size();
    }

    @Override
    public int getItemViewType(int position) {
        Object item = mData.get(position);
        if (item instanceof String) {
            return typeData;
        } else {
            return typeAd;
        }
    }


    static class DataViewHolder extends RecyclerView.ViewHolder {

        private final TextView tvTitle;

        public DataViewHolder(@NonNull View itemView) {
            super(itemView);
            tvTitle = (TextView) itemView;
        }
    }

    static class AdViewHolder extends RecyclerView.ViewHolder {

        private final FrameLayout flContainer;

        public AdViewHolder(@NonNull View itemView) {
            super(itemView);
            flContainer = (FrameLayout) itemView;
        }

        void showAd(NativeAdPageDataLoader.NativeAdDataHolder ad) {
            ad.showAd(flContainer);
        }
    }

}
