package com.mint.mintdemo.advanced.native_in_view_pager;

import static com.mint.mintdemo.Constants.NATIVE_PLACEMENT_ID;
import static com.mint.mintdemo.Util.appendInfo;

import android.os.Bundle;
import android.view.MenuItem;
import android.view.View;
import android.widget.ProgressBar;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;
import androidx.viewpager2.widget.ViewPager2;

import com.mint.mintdemo.R;
import com.mint.mintdemo.Util;
import com.mint.mintdemo.advanced.native_in_recycler.NativeAdPageDataLoader;
import com.mint.mintdemo.advanced.native_in_recycler.NativeAdRecyclerAdapter;
import com.mint.mintdemo.utils.pull_to_refresh.PullToRefreshViewController;

import java.util.List;

public class NativeAdInViewPager2Activity extends AppCompatActivity implements
        PullToRefreshViewController<Object> {


    private TextView mTvInfo;
    private ViewPager2 mViewPager;
    private ProgressBar mPbLoading;

    private final NativeAdRecyclerAdapter mAdapter = new NativeAdRecyclerAdapter(
            NativeAdRecyclerAdapter.TYPE_PAGER);
    private final NativeAdPageDataLoader mDataLoader = new NativeAdPageDataLoader(this,
            3, 3, new Util.Logger() {
        @Override
        public void printMsg(String msg) {
            appendInfo(mTvInfo, msg);
        }
    });

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_native_ad_in_view_pager2);

        ActionBar bar = getSupportActionBar();
        if (bar != null) {
            bar.setTitle(R.string.native_ad_in_viewpager);
            bar.setDisplayHomeAsUpEnabled(true);
        }

        mTvInfo = findViewById(R.id.tv_info);
        mViewPager = findViewById(R.id.vp);
        mPbLoading = findViewById(R.id.pb_loading);
        mViewPager.setAdapter(mAdapter);

        mViewPager.registerOnPageChangeCallback(new ViewPager2.OnPageChangeCallback() {


            @Override
            public void onPageSelected(int position) {
                if (mAdapter.mData == null || mAdapter.mData.isEmpty()) {
                    return;
                }

                if (position == mAdapter.mData.size() - 1) {
                    onLoadMore();
                }
            }

        });

        appendInfo(mTvInfo, "Placement ID: " + NATIVE_PLACEMENT_ID);
        appendInfo(mTvInfo, "Try to swipe right");
        onRefresh();
    }

    private void onRefresh() {
        if (mDataLoader.onRefresh(this)) {
            mPbLoading.setVisibility(View.VISIBLE);
        }
    }

    private void onLoadMore() {
        if (mDataLoader.onLoadMore(this)) {
            mPbLoading.setVisibility(View.VISIBLE);
        }
    }

    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        if (android.R.id.home == item.getItemId()) {
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    @Override
    public void onRefreshFinish(List<Object> data) {
        mPbLoading.setVisibility(View.INVISIBLE);
        mAdapter.onDataRefreshed(data);
    }

    @Override
    public void onLoadMoreFinish(List<Object> data) {
        mPbLoading.setVisibility(View.INVISIBLE);
        mAdapter.onDataAppend(data);
    }

}
