package com.mint.mintdemo.basic;

import static com.mint.mintdemo.Constants.BANNER_PLACEMENT_ID;
import static com.mint.mintdemo.Util.appendInfo;
import static com.mint.mintdemo.Util.dp2Px;

import android.os.Bundle;
import android.text.method.ScrollingMovementMethod;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.RelativeLayout;
import android.widget.Spinner;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;

import com.mint.mintdemo.R;
import com.zeus.gmc.sdk.mobileads.mintmediation.banner.AdSize;
import com.zeus.gmc.sdk.mobileads.mintmediation.banner.BannerAd;
import com.zeus.gmc.sdk.mobileads.mintmediation.banner.BannerAdListener;

import java.util.List;

public class BasicBannerActivity extends AppCompatActivity implements BannerAdListener,
        AdapterView.OnItemSelectedListener {

    private TextView mTvInfo;
    private RelativeLayout mAdContainer;
    private Spinner mSpAdSize;

    private BannerAd mMintBanner;

    private AdSize mAdSize = AdSize.BANNER;

    private AdSize[] mAdSizeList = new AdSize[] {
            AdSize.BANNER,
            AdSize.LEADERBOARD,
            AdSize.MEDIUM_RECTANGLE,
            AdSize.SMART};

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_basic_banner);

        ActionBar actionBar = getSupportActionBar();
        if (actionBar != null) {
            actionBar.setDisplayHomeAsUpEnabled(true);
            actionBar.setTitle(R.string.banner);
        }

        mAdContainer = findViewById(R.id.rl_container);
        mTvInfo = findViewById(R.id.tv_info);
        mSpAdSize = findViewById(R.id.sp_size);

        ArrayAdapter<AdSize> spinnerAdapter = new ArrayAdapter<AdSize>(this,
                android.R.layout.simple_dropdown_item_1line, mAdSizeList);
        mSpAdSize.setAdapter(spinnerAdapter);
        mSpAdSize.setOnItemSelectedListener(this);
        mTvInfo.setMovementMethod(new ScrollingMovementMethod());

        appendInfo(mTvInfo, "Placement ID: " + BANNER_PLACEMENT_ID);
        mMintBanner = new BannerAd(this, BANNER_PLACEMENT_ID, this);
    }

    public void onLoadClick(View view) {
        mSpAdSize.setEnabled(false);

        ViewGroup.LayoutParams layoutParams = mAdContainer.getLayoutParams();
        layoutParams.width = (int)dp2Px(mAdSize.getWidth());
        layoutParams.height = (int)dp2Px(mAdSize.getHeight());
        appendInfo(mTvInfo, "Load start ...");
        mMintBanner.setAdSize(mAdSize);
        mMintBanner.loadAd();
    }

    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        if (android.R.id.home == item.getItemId()) {
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }


    @Override
    public void onItemSelected(AdapterView<?> parent, View view, int position, long id) {
        if (mAdSize == mAdSizeList[position]) {
            return;
        }
        mAdSize = mAdSizeList[position];
    }

    @Override
    public void onNothingSelected(AdapterView<?> parent) {}

    @Override
    public void onAdReady(View view) {
        if (view == null) {
            return;
        }

        appendInfo(mTvInfo,"Ad impression");
        if (view.getParent() != null) {
            ((ViewGroup) view.getParent()).removeView(view);
        }
        mAdContainer.removeAllViews();

        RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(
                ViewGroup.LayoutParams.WRAP_CONTENT,
                ViewGroup.LayoutParams.WRAP_CONTENT);
        mAdContainer.addView(view, layoutParams);
    }

    @Override
    public void onAdFailed(String s) {
        appendInfo(mTvInfo,"Ad failed");
    }

    @Override
    public void onAdClicked() {
        appendInfo(mTvInfo,"Ad clicked");
    }


    @Override
    protected void onDestroy() {
        mMintBanner.destroy();
        super.onDestroy();
    }
}
