package com.mint.mintdemo.basic;

import static com.mint.mintdemo.Util.appendInfo;

import android.os.Bundle;
import android.text.method.ScrollingMovementMethod;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;

import com.mint.mintdemo.MainActivity;
import com.mint.mintdemo.R;
import com.zeus.gmc.sdk.mobileads.mintmediation.interstitial.InterstitialAd;
import com.zeus.gmc.sdk.mobileads.mintmediation.interstitial.InterstitialAdListener;
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.error.Error;
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.model.Scene;

public class BasicInterstitialActivity extends AppCompatActivity implements InterstitialAdListener {

    private TextView mTvInfo;
    private Button mBtnShow;
    private Button mBtnLoad;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_basic_interstitial);

        ActionBar bar = getSupportActionBar();
        if (bar != null) {
            bar.setDisplayHomeAsUpEnabled(true);
            bar.setTitle(R.string.interstitial);
        }
        mTvInfo = findViewById(R.id.tv_info);
        mBtnShow = findViewById(R.id.btn_show);
        mBtnLoad = findViewById(R.id.btn_load);

        mTvInfo.setMovementMethod(new ScrollingMovementMethod());

        InterstitialAd.setAdListener(this);

        boolean adAvailable = InterstitialAd.isReady();

        mBtnShow.setEnabled(adAvailable);
        if (adAvailable) {
            appendInfo(mTvInfo,  "Ad available, click show button to show ad");
        } else {
            appendInfo(mTvInfo, "Ad not available, click load button to load ad");
        }
    }

    public void onLoadClick(View view) {
        appendInfo(mTvInfo, "Ad load start ...");
        if (InterstitialAd.isReady()) {
            // Ad is ready, cancel load
            appendInfo(mTvInfo, "Ad Ready");
            return;
        }
        InterstitialAd.loadAd();
    }

    public void onShowClick(View view) {
        /* Optional:
         * Call enterAdScene wherever your application need show Ad,
         * will help you analyse Ad fill rate at mint mediation dashboard.
         *
         * params: placementId, sceneId
         */
        InterstitialAd.enterAdScene(null, null);

        if (InterstitialAd.isReady()) {
            InterstitialAd.showAd();
        }
    }

    @Override
    protected void onDestroy() {
        InterstitialAd.setAdListener(null);
        InterstitialAd.destroy();
        super.onDestroy();
    }


    @Override
    public void onInterstitialAdAvailabilityChanged(boolean ready) {
        appendInfo(mTvInfo, "Ready changed " + ready);
        if (ready) {
            appendInfo(mTvInfo, "click show button to show ad");
        }
        mBtnShow.setEnabled(ready);
    }

    @Override
    public void onInterstitialAdShowed(Scene scene) {
        appendInfo(mTvInfo, "Ad impression");
    }

    @Override
    public void onInterstitialAdShowFailed(Scene scene, Error error) {
        appendInfo(mTvInfo, "Ad show failed");
    }

    @Override
    public void onInterstitialAdClosed(Scene scene) {
        appendInfo(mTvInfo, "Ad close");
    }

    @Override
    public void onInterstitialAdClicked(Scene scene) {
        appendInfo(mTvInfo, "Ad click");
    }


    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        if (android.R.id.home == item.getItemId()) {
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }
}
