package com.mint.mintdemo.basic;

import static com.mint.mintdemo.Constants.NATIVE_PLACEMENT_ID;
import static com.mint.mintdemo.Util.appendInfo;

import android.os.Bundle;
import android.text.method.ScrollingMovementMethod;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.FrameLayout;
import android.widget.ImageView;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.ActionBar;
import androidx.appcompat.app.AppCompatActivity;

import com.mint.mintdemo.R;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.AdIconView;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.MediaView;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.NativeAd;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.NativeAdListener;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.NativeAdLoader;
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.NativeAdView;

public class BasicNativeActivity extends AppCompatActivity implements NativeAdListener {

    private FrameLayout mFlContainer;
    private TextView mTvInfo;

    private NativeAdLoader mNativeAdLoader;
    private NativeAd mNativeAd;

    @Override
    protected void onCreate(@Nullable Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_basic_native);

        ActionBar bar = getSupportActionBar();
        if (bar != null) {
            bar.setDisplayHomeAsUpEnabled(true);
            bar.setTitle(R.string._native);
        }
        mTvInfo = findViewById(R.id.tv_info);
        mFlContainer = findViewById(R.id.fl_container);

        mTvInfo.setMovementMethod(new ScrollingMovementMethod());
        appendInfo(mTvInfo, "Placement ID:" + NATIVE_PLACEMENT_ID);

        findViewById(R.id.btn_load).setOnClickListener(this::onLoadClick);
    }


    @Override
    public boolean onOptionsItemSelected(@NonNull MenuItem item) {
        if (android.R.id.home == item.getItemId()) {
            finish();
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    public void onLoadClick(View view) {
        appendInfo(mTvInfo, "Ad load start ...");
        if (mNativeAdLoader == null) {
            mNativeAdLoader = new NativeAdLoader(this, NATIVE_PLACEMENT_ID, this);
        }
        mNativeAdLoader.loadAd();
    }

    @Override
    public void onAdReady() {
        mFlContainer.removeAllViews();

        NativeAd adInfo = mNativeAdLoader.getNativeAd();
        if (adInfo == null) {
            return;
        }
        if (mNativeAd != null) {
            mNativeAd.destroy();
        }

        View nativeView = getLayoutInflater().inflate(R.layout.simple_native_layout, null,
                false);
        TextView tvTitle = nativeView.findViewById(R.id.tv_title);
        tvTitle.setText(adInfo.getTitle());

        TextView tvDesc = nativeView.findViewById(R.id.tv_desc);
        tvDesc.setText(adInfo.getDesc());

        Button btnCta = nativeView.findViewById(R.id.btn_cta);
        btnCta.setText(adInfo.getCallToActionText());

        AdIconView iconView = nativeView.findViewById(R.id.mint_icon_view);
        MediaView mediaView = nativeView.findViewById(R.id.mint_media_view);

        // media view image scale type
        mediaView.setImageScaleType(ImageView.ScaleType.CENTER_INSIDE);

        TextView advertiser = nativeView.findViewById(R.id.tv_ad);

        NativeAdView mintAdView = new NativeAdView(this);
        mintAdView.addView(nativeView);
        mintAdView.setTitleView(tvTitle);
        mintAdView.setDescView(tvDesc);
        mintAdView.setAdIconView(iconView);
        mintAdView.setCallToActionView(btnCta);
        mintAdView.setMediaView(mediaView);
        mintAdView.setAdvertiserView(advertiser);

        // only for yandex
        TextView domainView = nativeView.findViewById(R.id.ad_yandex_domain_view);
        TextView priceView = nativeView.findViewById(R.id.ad_yandex_price_view);
        TextView sponsoredView = nativeView.findViewById(R.id.ad_yandex_sponsored_view);
        TextView warningView = nativeView.findViewById(R.id.ad_yandex_warning_view);
        ImageView feedbackView = nativeView.findViewById(R.id.ad_yandex_feedback_view);
        mintAdView.setDomainView(domainView);
        mintAdView.setPriceView(priceView);
        mintAdView.setSponsoredView(sponsoredView);
        mintAdView.setWarningView(warningView);
        mintAdView.setFeedbackView(feedbackView);

        adInfo.registerNativeAdView(mintAdView);
        FrameLayout.LayoutParams layoutParams = new FrameLayout.LayoutParams(
                FrameLayout.LayoutParams.WRAP_CONTENT, FrameLayout.LayoutParams.WRAP_CONTENT);
        mFlContainer.addView(mintAdView, layoutParams);

        appendInfo(mTvInfo, "Ad impression");

        mNativeAd = adInfo;
    }

    @Override
    public void onAdFailed(String s) {
        appendInfo(mTvInfo, "Ad failed");
        appendInfo(mTvInfo, s);
    }

    @Override
    public void onAdClicked() {
        appendInfo(mTvInfo, "Ad click");
    }

    @Override
    protected void onDestroy() {
        if (mNativeAd != null) {
            mNativeAd.destroy();
        }
        if (mNativeAdLoader != null) {
            mNativeAdLoader.destroy();
        }
        super.onDestroy();
    }
}
