package com.mint.mintdemo.utils.pull_to_refresh;

import java.util.ArrayList;
import java.util.List;

public abstract class BasePullToRefreshDataLoader<T> implements PullToRefreshDataLoader<T> {


    public interface PageDataCallback<T> {
        void onDataLoad(List<T> data);
    }

    private int mState = STATE_IDLE;

    private List<T> mTotalData = new ArrayList<T>();

    private int mPageNo = 1;


    @Override
    public boolean onRefresh(PullToRefreshViewController<T> controller) {
        if (STATE_IDLE != mState) {
            return false;
        }
        mState = STATE_REFRESH;
        mPageNo = 1;
        loadData(mPageNo, new PageDataCallback<T>() {
            @Override
            public void onDataLoad(List<T> data) {
                mTotalData.clear();
                mTotalData.addAll(data);
                mState = STATE_IDLE;
                controller.onRefreshFinish(mTotalData);
            }
        });
        return true;
    }

    @Override
    public boolean onLoadMore(PullToRefreshViewController<T> controller) {
        if (STATE_IDLE != mState) {
            return false;
        }
        mState = STATE_LOAD_MORE;
        loadData(mPageNo + 1, new PageDataCallback<T>() {
            @Override
            public void onDataLoad(List<T> data) {
                mTotalData.addAll(data);
                mState = STATE_IDLE;
                mPageNo += 1;
                controller.onLoadMoreFinish(mTotalData);
            }
        });
        return true;
    }

    protected abstract void loadData(int pageNo, PageDataCallback<T> callback);
}
