package com.mint.mintdemo

import android.content.Intent
import android.os.Bundle
import android.text.SpannableStringBuilder
import android.text.style.ForegroundColorSpan
import android.view.Menu
import android.view.MenuItem
import android.view.View
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import androidx.core.text.set
import androidx.preference.PreferenceManager
import com.mint.mintdemo.advanced.native_in_recycler.NativeAdInRecyclerViewActivity
import com.mint.mintdemo.advanced.native_in_view_pager.NativeAdInViewPager2Activity
import com.mint.mintdemo.basic.*
import com.yandex.mobile.ads.common.MobileAds
import com.zeus.gmc.sdk.mobileads.mintmediation.InitCallback
import com.zeus.gmc.sdk.mobileads.mintmediation.InitOptions
import com.zeus.gmc.sdk.mobileads.mintmediation.MintAds
import com.zeus.gmc.sdk.mobileads.mintmediation.testsuite.TestSuite
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.error.Error


class MainActivity : AppCompatActivity() {

    lateinit var mTvInitState: TextView

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_main)

        val sp = PreferenceManager.getDefaultSharedPreferences(this)
        if (sp.getBoolean(KEY_FIRST_OPEN, true)) {
            sp.edit()
                .putString(KEY_MINT_APP_KEY, MINT_APP_KEY)
                .putBoolean(KEY_FIRST_OPEN, false)
                .putBoolean(KEY_PRELOAD_INTERSTITIAL, true)
                .putBoolean(KEY_PRELOAD_REWARDED_VIDEO, true)
                .putBoolean(KEY_GDPR, false)
                .putString(KEY_COPPA, "Not Set")
                .putString(KEY_CCPA, "Not Set")
                .apply()
        }

        supportActionBar?.setDisplayShowTitleEnabled(false)
        supportActionBar?.setDisplayUseLogoEnabled(true)
        supportActionBar?.setDisplayShowHomeEnabled(true)
        supportActionBar?.setLogo(R.drawable.mint_logo)

        val preloadInterstitial = sp.getBoolean(KEY_PRELOAD_INTERSTITIAL, true)
        val preloadRewardedVideo = sp.getBoolean(KEY_PRELOAD_REWARDED_VIDEO, true)
        val preloadRewardedInterstitial = sp.getBoolean(KEY_PRELOAD_REWARDED_INTERSTITIAL, false)
        val appKey = sp.getString(KEY_MINT_APP_KEY, MINT_APP_KEY)
        val gdprConsent = sp.getBoolean(KEY_GDPR, false)
        val ccpa = sp.getString(KEY_CCPA, "Not Set")
        val coppa = sp.getString(KEY_COPPA, "Not Set")
        val userExperience = sp.getBoolean(KEY_USER_EXPERIENCE, false)
        val age = sp.getInt(KEY_AGE, -1)
        val gender = sp.getString(KEY_GENDER, null)

        mTvInitState = findViewById(R.id.tv_init_state)

        setHeaderText(findViewById(R.id.tv_version), "SDK VERSION:", MintAds.getSDKVersion())

        if ("Limited" == ccpa) {
            MintAds.setUSPrivacyLimit(true)
        } else if ("Not Limit" == ccpa) {
            MintAds.setUSPrivacyLimit(false)
        }
        // User age restricted
        if ("Limited" == coppa) {
            MintAds.setAgeRestricted(true)
        } else if ("Not Limit" == coppa) {
            MintAds.setAgeRestricted(false)
        }

        // User experience on
        MintAds.setUserExperienceOn(userExperience)

        if ("Male" == gender) {
            MintAds.setUserGender("male")
        } else if ("Female" == gender) {
            MintAds.setUserGender("female")
        }
        if (-1 != age) {
            MintAds.setUserAge(age)
        }

        MintAds.setDebugEnable(true)

        MintAds.setCustomDeviceId("YOUR CUSTOM DEVICE ID")

        // yandex test mode, for yandex only
        MobileAds.enableLogging(true)
        MobileAds.enableDebugErrorIndicator(true)


        // set ad impression data listener, this will callback ad impress result, optional
        MintAds.setImpressionDataListener {
            printLogV("Ad impression result: $it")
            // ad type, Banner\Native\Splash\Interstitial\RewardedVideo\RewardedInterstitial
            val adType: String = it.adType
            // ISO 4217 currency code, e.g. USD, CNY, JPY, etc.
            val cur: String = it.currency
            // country name, such as cn, us, jp, etc.
            val country: String = it.country
            // ad network name, such as AdMob, Facebook, Unity, Vungle, etc.
            val mediation: String? = it.mediationId
            // Mint Mediation placement id
            val placementId: String = it.placementId
            // impression revenue
            val revenue: Double = it.revenue
        }

        // Before SDK init, you must set GDPR consent value
        MintAds.setGDPRConsent(gdprConsent)


        // sdk init
        val preloadTypeList = ArrayList<MintAds.PRELOAD_AD_TYPE>()
        if (preloadInterstitial) {
            preloadTypeList.add(MintAds.PRELOAD_AD_TYPE.INTERSTITIAL)
        }
        if (preloadRewardedVideo) {
            preloadTypeList.add(MintAds.PRELOAD_AD_TYPE.REWARDED_VIDEO)
        }
        if (preloadRewardedInterstitial) {
            preloadTypeList.add(MintAds.PRELOAD_AD_TYPE.REWARDED_INTERSTITIAL)
        }
        if (preloadTypeList.isEmpty()) {
            preloadTypeList.add(MintAds.PRELOAD_AD_TYPE.NONE)
        }

        val mintInitOptions = InitOptions.Builder()
            .appKey(appKey)
            .preloadAdTypes(*preloadTypeList.toTypedArray())
            .channel("YOUR CHANNEL")
            .build()

        setHeaderText(mTvInitState, "INIT STATE:", "Loading...")
        printLogV("Init with appkey: $appKey")

        MintAds.init(mintInitOptions, object: InitCallback {
            override fun onSuccess() {
                MintAds.setIAP(5.0f, "USD")
                setHeaderText(mTvInitState, "INIT STATE:", "success")
            }

            override fun onError(p0: Error?) {
                setHeaderText(mTvInitState, "INIT STATE:", "error")
            }
        })
    }

    override fun onCreateOptionsMenu(menu: Menu?): Boolean {
        menuInflater.inflate(R.menu.menu_main, menu)
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (R.id.action_setting == item.itemId) {
            startActivity(Intent(this, SettingsActivity::class.java))
            return true
        }
        return super.onOptionsItemSelected(item)
    }

    fun onBasicBannerClick(view: View) {
        startActivity(Intent(this, BasicBannerActivity::class.java))
    }

    fun onBasicNativeClick(view: View) {
        startActivity(Intent(this, BasicNativeActivity::class.java))
    }

    fun onBasicSplashClick(view: View) {
        startActivity(Intent(this, BasicSplashActivity::class.java))
    }

    fun onBasicInterstitialClick(view: View) {
        startActivity(Intent(this, BasicInterstitialActivity::class.java))
    }

    fun onBasicRewardedVideoClick(view: View) {
        startActivity(Intent(this, BasicRewardedVideoActivity::class.java))
    }

    fun onBasicRewardedInterstitialClick(view: View) {
        startActivity(Intent(this, BasicRewardedInterstitialActivity::class.java))
    }

    fun onNativeRecyclerClick(view: View) {
        startActivity(Intent(this, NativeAdInRecyclerViewActivity::class.java))
    }

    fun onNativeViewPagerClick(view: android.view.View) {
        startActivity(Intent(this, NativeAdInViewPager2Activity::class.java))
    }


    fun onTestSuiteClick(view: View) {
        val sp = PreferenceManager.getDefaultSharedPreferences(this)
        val appKey = sp.getString(KEY_MINT_APP_KEY, MINT_APP_KEY) ?: return
        TestSuite.open(this, appKey)
    }


    private fun setHeaderText(tv: TextView, title: String, message: String) {
        val str = "$title $message"
        val ssb = SpannableStringBuilder(str)
        ssb[title.length, str.length] = ForegroundColorSpan(0x70ffffff)
        tv.text = ssb
    }


}