package com.mint.mintdemo.advanced.native_in_recycler

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.text.method.ScrollingMovementMethod
import android.view.MenuItem
import android.view.View
import android.widget.ProgressBar
import android.widget.TextView
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import androidx.recyclerview.widget.RecyclerView.OnScrollListener
import androidx.swiperefreshlayout.widget.SwipeRefreshLayout
import com.mint.mintdemo.NATIVE_PLACEMENT_ID
import com.mint.mintdemo.R
import com.mint.mintdemo.appendInfo
import com.mint.mintdemo.utils.pull_to_refresh.PullToRefreshViewController

class NativeAdInRecyclerViewActivity : AppCompatActivity(), SwipeRefreshLayout.OnRefreshListener,
    PullToRefreshViewController<Any> {

    private val mDataLoader = NativeAdPageDataLoader(this, 20, 20) {
        appendInfo(mTvInfo, it)
    }
    private val mAdapter = NativeAdRecyclerAdapter(TYPE_LIST)

    lateinit var mTvInfo: TextView
    lateinit var mRecyclerView: RecyclerView
    lateinit var mRefreshLayout: SwipeRefreshLayout
    lateinit var mPbLoadMore: ProgressBar


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_native_ad_in_recycler_view)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = getString(R.string.native_in_recycler_view)

        mTvInfo = findViewById(R.id.tv_info)
        mRecyclerView = findViewById(R.id.rv)
        mRefreshLayout = findViewById(R.id.srl)
        mPbLoadMore = findViewById(R.id.pb_load_more)

        mTvInfo.movementMethod = ScrollingMovementMethod()

        mRecyclerView.layoutManager = LinearLayoutManager(this)
        mRecyclerView.adapter = mAdapter

        mRefreshLayout.setOnRefreshListener(this)
        mRecyclerView.addOnScrollListener(object: OnScrollListener() {

            override fun onScrollStateChanged(recyclerView: RecyclerView, newState: Int) {
                if (mAdapter.mData == null || mAdapter.mData!!.isEmpty()) {
                    return
                }
                if (!recyclerView.canScrollVertically(1) &&
                    RecyclerView.SCROLL_STATE_IDLE == newState) {
                    // recycler view scroll to bottom
                    onLoadMore()
                }
            }
        })

        appendInfo(mTvInfo, "Placement ID: $NATIVE_PLACEMENT_ID")

        mRefreshLayout.isRefreshing = true
        onRefresh()
    }

    override fun onRefresh() {
        if (!mDataLoader.onRefresh(this)) {
            mRefreshLayout.isRefreshing = false
        }
    }

    fun onLoadMore() {
        if (mDataLoader.onLoadMore(this)) {
            mRefreshLayout.isEnabled = false
        }
        mPbLoadMore.visibility = View.VISIBLE
    }

    override fun onRefreshFinish(data: List<Any>) {
        mRefreshLayout.isRefreshing = false
        mAdapter.onDataRefreshed(data)
    }

    override fun onLoadMoreFinish(data: List<Any>) {
        mRefreshLayout.isEnabled = true
        mPbLoadMore.visibility = View.INVISIBLE
        mAdapter.onDataAppend(data)
    }


    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            finish()
            return true
        }
        return super.onOptionsItemSelected(item)
    }

    override fun onDestroy() {
        super.onDestroy()
        mDataLoader.onDestroy()
    }

}




