package com.mint.mintdemo.advanced.native_in_recycler

import android.app.Activity
import android.os.Handler
import android.os.Looper
import android.view.LayoutInflater
import android.widget.*
import com.mint.mintdemo.Logger
import com.mint.mintdemo.NATIVE_PLACEMENT_ID
import com.mint.mintdemo.R
import com.mint.mintdemo.utils.pull_to_refresh.BasePullToRefreshDataLoader
import com.mint.mintdemo.utils.pull_to_refresh.PageDataCallback
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.*
import java.util.*
import java.util.concurrent.atomic.AtomicInteger


class NativeAdPageDataLoader(private val activity: Activity,
                             private val pageSize: Int,
                             private val nativeAdGap: Int,
                             private val logger: Logger) :
    BasePullToRefreshDataLoader<Any>(), NativeAdListener {

    private val mAvailableNativePool = ArrayList<NativeAdDataHolder>()
    private val mRenderedNativePool = ArrayList<NativeAdDataHolder>()

    private val mAdLoader: NativeAdLoader = NativeAdLoader(activity, NATIVE_PLACEMENT_ID, this)


    override fun loadData(pageNo: Int, callback: PageDataCallback<Any>) {
        val pageAdCount = pageSize / nativeAdGap
        mAdLoader.loadAd()
        Handler(Looper.getMainLooper()).postDelayed({
            val totalDataCount = pageSize + pageAdCount;
            val result = ArrayList<Any>(totalDataCount)

            DATA@ for (i in 0 until pageSize) {
                val realIndex = ((pageNo - 1) * pageSize) + i
                result.add("Item index $realIndex")
                if (realIndex % nativeAdGap == 0) {
                    // ad position, insert ad
                    val nativeAd = mAdLoader.getNativeAd()
                    if (nativeAd == null) {
                        mAdLoader.loadAd()
                    } else {
                        logger("Insert Ad after $realIndex")
                        val adHolder = NativeAdDataHolder(nativeAd)
                        mAvailableNativePool.add(adHolder)
                        result.add(adHolder)
                    }
                }
            }

            if (pageNo == 1) {
                // remove rendered add
                clearRenderedAd()
            }

            callback(result)
        }, 3000)
    }

    fun onDestroy() {
        for (adHolder in mAvailableNativePool) {
            adHolder.nativeAd.destroy()
        }
        mAvailableNativePool.clear()
        for (adHolder in mRenderedNativePool) {
            adHolder.nativeAd.destroy()
        }
        mRenderedNativePool.clear()
        mAdLoader.destroy()
    }


    private fun clearRenderedAd() {
        for (adHolder in mRenderedNativePool) {
            adHolder.nativeAd.destroy()
        }
        mRenderedNativePool.clear()
    }

    private fun onAdRendered(adHolder: NativeAdDataHolder) {
        mRenderedNativePool.add(adHolder)
        mAvailableNativePool.remove(adHolder)
    }

    inner class NativeAdDataHolder(val nativeAd: NativeAd) {

        private var mAdRender: AdRender? = null

        fun showAd(container: FrameLayout) {
            if (mAdRender == null) {
                mAdRender = AdRender()
            }
            mAdRender!!.render(container, nativeAd)
            onAdRendered(this)
        }
    }

    inner class AdRender() {

        var cachedAdView: NativeAdView? = null


        fun render(container: FrameLayout, adInfo: NativeAd?) {

            if (cachedAdView == null) {
                val mintAdView = NativeAdView(container.context)
                val simpleAdView = LayoutInflater.from(container.context)
                    .inflate(R.layout.simple_native_layout, mintAdView, false) as RelativeLayout
                val tvTitle = simpleAdView.findViewById<TextView>(R.id.tv_title)
                val tvDesc = simpleAdView.findViewById<TextView>(R.id.tv_desc)
                val btnCta = simpleAdView.findViewById<Button>(R.id.btn_cta)
                val iconView = simpleAdView.findViewById<AdIconView>(R.id.mint_icon_view)
                val mediaView = simpleAdView.findViewById<MediaView>(R.id.mint_media_view)
                val advertiser = simpleAdView.findViewById<TextView>(R.id.tv_ad)

                mintAdView.addView(simpleAdView)
                mintAdView.titleView = tvTitle
                mintAdView.descView = tvDesc
                mintAdView.adIconView = iconView
                mintAdView.callToActionView = btnCta
                mintAdView.mediaView = mediaView
                mintAdView.advertiserView = advertiser

                // only for yandex
                val domainView = simpleAdView.findViewById<TextView>(R.id.ad_yandex_domain_view)
                val priceView = simpleAdView.findViewById<TextView>(R.id.ad_yandex_price_view)
                val sponsoredView =
                    simpleAdView.findViewById<TextView>(R.id.ad_yandex_sponsored_view)
                val warningView = simpleAdView.findViewById<TextView>(R.id.ad_yandex_warning_view)
                val feedbackView =
                    simpleAdView.findViewById<ImageView>(R.id.ad_yandex_feedback_view)
                mintAdView.domainView = domainView
                mintAdView.priceView = priceView
                mintAdView.sponsoredView = sponsoredView
                mintAdView.warningView = warningView
                mintAdView.feedbackView = feedbackView

                val displayMetrics = container.context.resources.displayMetrics
                mediaView.layoutParams.height = (displayMetrics.widthPixels / (1200.0 / 627.0)).toInt()
                mediaView.imageScaleType = ImageView.ScaleType.CENTER_INSIDE
                val layoutParams = FrameLayout.LayoutParams(FrameLayout.LayoutParams.MATCH_PARENT,
                    FrameLayout.LayoutParams.WRAP_CONTENT)

                tvTitle.text = adInfo?.title
                tvDesc.text = adInfo?.desc
                btnCta.text = adInfo?.callToActionText
                adInfo?.registerNativeAdView(mintAdView)

                container.removeAllViews()
                container.addView(mintAdView, layoutParams)

                cachedAdView = mintAdView
            } else {
                container.removeAllViews()
                container.addView(cachedAdView)
            }
        }
    }

    override fun onAdReady() {
    }

    override fun onAdFailed(p0: String?) {
    }

    override fun onAdClicked() {
    }
}

