package com.mint.mintdemo.advanced.native_in_recycler

import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.*
import androidx.recyclerview.widget.RecyclerView
import com.mint.mintdemo.R

const val TYPE_LIST = 1
const val TYPE_PAGER = 2

class NativeAdRecyclerAdapter(private val type: Int)  : RecyclerView.Adapter<RecyclerView.ViewHolder>() {

    private val typeData = 1
    private val typeAd = 2

    var mData: List<Any>? = null

    fun onDataRefreshed(data: List<Any>) {
        mData = data
        notifyDataSetChanged()
    }

    fun onDataAppend(data: List<Any>) {
        if (mData != null) {
            val startIndex = mData!!.size
            mData = data
            notifyItemRangeInserted(startIndex, data.size)
        } else {
            mData = data
            notifyDataSetChanged()
        }
    }

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): RecyclerView.ViewHolder {
        return if (viewType == typeData) {
            if (type == TYPE_PAGER) {
                DataViewHolder(LayoutInflater.from(parent.context).inflate(R.layout.item_pager_data, parent, false))
            } else {
                DataViewHolder(LayoutInflater.from(parent.context).inflate(android.R.layout.simple_list_item_1, parent, false))
            }
        } else {
            if (type == TYPE_PAGER) {
                AdViewHolder(LayoutInflater.from(parent.context).inflate(R.layout.item_pager_ad, parent, false))
            } else {
                AdViewHolder(FrameLayout(parent.context))
            }
        }
    }

    override fun onBindViewHolder(holder: RecyclerView.ViewHolder, position: Int) {
        val type = getItemViewType(position)
        if (typeData == type) {
            (holder as DataViewHolder).tvTitle.text = mData!![position].toString()
        } else {
            // show ad
            val adInfoHolder = mData!![position] as NativeAdPageDataLoader.NativeAdDataHolder
            (holder as AdViewHolder).showAd(adInfoHolder)
        }
    }

    override fun getItemViewType(position: Int): Int {
        val item = mData!![position]
        return if (item is String) {
            typeData
        } else {
            typeAd
        }
    }

    override fun getItemCount(): Int {
        return if (mData == null) {
            0
        } else {
            mData!!.size
        }
    }


    class DataViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {

        val tvTitle: TextView = itemView as TextView

    }

    class AdViewHolder(itemView: View) : RecyclerView.ViewHolder(itemView) {

        private val flContainer: FrameLayout = itemView as FrameLayout

        fun showAd(ad: NativeAdPageDataLoader.NativeAdDataHolder) {
            ad.showAd(flContainer)
        }
    }

}