package com.mint.mintdemo.advanced.native_in_view_pager

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.view.MenuItem
import android.view.View
import android.widget.ProgressBar
import android.widget.TextView
import androidx.viewpager2.widget.ViewPager2
import com.mint.mintdemo.NATIVE_PLACEMENT_ID
import com.mint.mintdemo.R
import com.mint.mintdemo.advanced.native_in_recycler.NativeAdPageDataLoader
import com.mint.mintdemo.advanced.native_in_recycler.NativeAdRecyclerAdapter
import com.mint.mintdemo.advanced.native_in_recycler.TYPE_PAGER
import com.mint.mintdemo.appendInfo
import com.mint.mintdemo.utils.pull_to_refresh.PullToRefreshViewController

class NativeAdInViewPager2Activity : AppCompatActivity(), PullToRefreshViewController<Any> {



    lateinit var mTvInfo: TextView
    lateinit var mViewPager: ViewPager2
    lateinit var mPbLoading: ProgressBar

    private val mAdapter = NativeAdRecyclerAdapter(TYPE_PAGER)
    private val mDataLoader = NativeAdPageDataLoader(this, 3, 3) {
        appendInfo(mTvInfo, it)
    }


    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_native_ad_in_view_pager2)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = getString(R.string.native_in_view_pager)

        mTvInfo = findViewById(R.id.tv_info)
        mViewPager = findViewById(R.id.vp)
        mPbLoading = findViewById(R.id.pb_loading)
        mViewPager.adapter = mAdapter

        mViewPager.registerOnPageChangeCallback(object: ViewPager2.OnPageChangeCallback() {
            override fun onPageSelected(position: Int) {
                if (mAdapter.mData == null || mAdapter.mData!!.isEmpty()) {
                    return
                }

                if (position == mAdapter.mData!!.size - 1) {
                    onLoadMore()
                }
            }
        })

        appendInfo(mTvInfo, "Placement ID: $NATIVE_PLACEMENT_ID")
        appendInfo(mTvInfo, "Try to swipe right")
        onRefresh()
    }


    private fun onRefresh() {
        if (mDataLoader.onRefresh(this)) {
            mPbLoading.visibility = View.VISIBLE
        }
    }

    private fun onLoadMore() {
        if (mDataLoader.onLoadMore(this)) {
            mPbLoading.visibility = View.VISIBLE
        }
    }


    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            finish()
            return true
        }
        return super.onOptionsItemSelected(item)
    }

    override fun onRefreshFinish(data: List<Any>) {
        mPbLoading.visibility = View.INVISIBLE
        mAdapter.onDataRefreshed(data)
    }

    override fun onLoadMoreFinish(data: List<Any>) {
        mPbLoading.visibility = View.INVISIBLE
        mAdapter.onDataAppend(data)
    }

}