package com.mint.mintdemo.basic

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.text.method.ScrollingMovementMethod
import android.view.MenuItem
import android.view.View
import android.view.ViewGroup
import android.widget.*
import com.mint.mintdemo.BANNER_PLACEMENT_ID
import com.mint.mintdemo.R
import com.mint.mintdemo.appendInfo
import com.zeus.gmc.sdk.mobileads.mintmediation.banner.AdSize
import com.zeus.gmc.sdk.mobileads.mintmediation.banner.BannerAd
import com.zeus.gmc.sdk.mobileads.mintmediation.banner.BannerAdListener
import android.widget.RelativeLayout
import com.mint.mintdemo.toPx

class BasicBannerActivity : AppCompatActivity(), BannerAdListener,
    AdapterView.OnItemSelectedListener {

    private lateinit var mTvInfo: TextView
    private lateinit var mAdContainer: RelativeLayout
    private lateinit var mSpAdSize: Spinner

    private lateinit var mMintBanner: BannerAd

    private var mAdSize = AdSize.BANNER
    private val mAdSizeList = MutableList(4) {
        when (it) {
            0 -> {
                AdSize.BANNER
            }
            1 -> {
                AdSize.LEADERBOARD
            }
            2 -> {
                AdSize.MEDIUM_RECTANGLE
            }
            else -> {
                AdSize.SMART
            }
        }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_basic_banner)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)

        mAdContainer = findViewById(R.id.rl_container)
        mTvInfo = findViewById(R.id.tv_info)
        mSpAdSize = findViewById(R.id.sp_size)


        val spinnerAdapter = ArrayAdapter(this,
            android.R.layout.simple_dropdown_item_1line, mAdSizeList)
        mSpAdSize.adapter = spinnerAdapter
        mSpAdSize.onItemSelectedListener = this

        mTvInfo.movementMethod = ScrollingMovementMethod()

        supportActionBar?.title = getString(R.string.banner)

        appendInfo(mTvInfo,"Placement ID: $BANNER_PLACEMENT_ID")
        mMintBanner = BannerAd(this, BANNER_PLACEMENT_ID, this)

    }

    fun onLoadClick(view: View) {
        mSpAdSize.isEnabled = false

        val layoutParams = mAdContainer.layoutParams
        layoutParams.width = mAdSize.width.toPx.toInt()
        layoutParams.height = mAdSize.height.toPx.toInt()

        appendInfo(mTvInfo,"Load start ...")
        mMintBanner.setAdSize(mAdSize)
        mMintBanner.loadAd()
    }


    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            finish()
            return true
        }
        return super.onOptionsItemSelected(item)
    }

    override fun onItemSelected(parent: AdapterView<*>?, view: View?,
                                position: Int, id: Long) {
        val newSize = when (position) {
            0 -> {
                AdSize.BANNER
            }
            1 -> {
                AdSize.LEADERBOARD
            }
            2 -> {
                AdSize.MEDIUM_RECTANGLE
            }
            else -> {
                AdSize.SMART
            }
        }

        if (mAdSize == newSize) {
            return
        }
        mAdSize = newSize
    }

    override fun onNothingSelected(parent: AdapterView<*>?) {}

    override fun onAdReady(adView: View?) {
        appendInfo(mTvInfo,"Ad impression")
        if (adView?.parent != null) {
            (adView.parent as ViewGroup?)?.removeView(adView)
        }
        mAdContainer.removeAllViews()

        val layoutParams = RelativeLayout.LayoutParams(ViewGroup.LayoutParams.WRAP_CONTENT,
            ViewGroup.LayoutParams.WRAP_CONTENT)
        mAdContainer.addView(adView, layoutParams)
    }

    override fun onAdFailed(p0: String?) {
        appendInfo(mTvInfo,"Ad failed")
    }

    override fun onAdClicked() {
        appendInfo(mTvInfo,"Ad clicked")
    }

    override fun onDestroy() {
        mMintBanner.destroy()
        super.onDestroy()
    }



}