package com.mint.mintdemo.basic

import android.os.Bundle
import android.text.method.ScrollingMovementMethod
import android.view.MenuItem
import android.view.View
import android.widget.Button
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import com.mint.mintdemo.MainActivity
import com.mint.mintdemo.R
import com.mint.mintdemo.appendInfo
import com.zeus.gmc.sdk.mobileads.mintmediation.interstitial.InterstitialAd
import com.zeus.gmc.sdk.mobileads.mintmediation.interstitial.InterstitialAdListener
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.error.Error
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.model.Scene

class BasicInterstitialActivity : AppCompatActivity(), InterstitialAdListener {

    private lateinit var mTvInfo: TextView
    private lateinit var mBtnShow: Button
    private lateinit var mBtnLoad: Button

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_basic_interstitial)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = getString(R.string.interstitial)

        mTvInfo = findViewById(R.id.tv_info)
        mBtnShow = findViewById(R.id.btn_show)
        mBtnLoad = findViewById(R.id.btn_load)

        mTvInfo.movementMethod = ScrollingMovementMethod()

        InterstitialAd.setAdListener(this)

        val adAvailable = InterstitialAd.isReady()

        mBtnShow.isEnabled = adAvailable
        if (adAvailable) {
            appendInfo(mTvInfo, "Ad available, click show button to show ad")
        } else {
            appendInfo(mTvInfo, "Ad not available, click load button to load ad")
        }
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            finish()
            return true
        }
        return super.onOptionsItemSelected(item)
    }

    fun onLoadClick(view: View) {
        appendInfo(mTvInfo, "Ad load start ...")
        if (InterstitialAd.isReady()) {
            // Ad is ready, cancel load
            appendInfo(mTvInfo, "Ad Ready")
            return
        }
        InterstitialAd.loadAd()
    }

    fun onShowClick(view: View) {
        /* Optional:
         * Call enterAdScene wherever your application need show Ad,
         * will help you analyse Ad fill rate at mint mediation dashboard.
         *
         * params: placementId, sceneId
         */
        InterstitialAd.enterAdScene(null, null)

        if (InterstitialAd.isReady()) {
            InterstitialAd.showAd()
        }
    }

    override fun onDestroy() {
        super.onDestroy()

        InterstitialAd.setAdListener(null)
        InterstitialAd.destroy()
    }


    override fun onInterstitialAdAvailabilityChanged(ready: Boolean) {
        appendInfo(mTvInfo, "Ready changed $ready")
        if (ready) {
            appendInfo(mTvInfo, "click show button to show ad")
        }
        mBtnShow.isEnabled = ready
    }

    override fun onInterstitialAdShowed(p0: Scene?) {
        appendInfo(mTvInfo, "Ad impression")
    }

    override fun onInterstitialAdShowFailed(p0: Scene?, p1: Error?) {
        appendInfo(mTvInfo, "Ad show failed")
    }

    override fun onInterstitialAdClosed(p0: Scene?) {
        appendInfo(mTvInfo, "Ad close")
    }

    override fun onInterstitialAdClicked(p0: Scene?) {
        appendInfo(mTvInfo, "Ad click")
    }
}