package com.mint.mintdemo.basic

import android.os.Bundle
import android.text.method.ScrollingMovementMethod
import android.view.MenuItem
import android.view.View
import android.widget.Button
import android.widget.FrameLayout
import android.widget.ImageView
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import com.mint.mintdemo.NATIVE_PLACEMENT_ID
import com.mint.mintdemo.R
import com.mint.mintdemo.appendInfo
import com.zeus.gmc.sdk.mobileads.mintmediation.nativead.*

class BasicNativeActivity : AppCompatActivity(), NativeAdListener {

    lateinit var mFlContainer: FrameLayout
    lateinit var mTvInfo: TextView

    private var mNativeAdLoader: NativeAdLoader? = null
    private var mNativeAd: NativeAd? = null

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_basic_native)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = getString(R.string._native)

        mTvInfo = findViewById(R.id.tv_info)
        mFlContainer = findViewById(R.id.fl_container)

        mTvInfo.movementMethod = ScrollingMovementMethod()

        appendInfo(mTvInfo, "Placement ID: $NATIVE_PLACEMENT_ID")

        findViewById<View>(R.id.btn_load).setOnClickListener { view: View? ->
            onLoadClick(
                view!!
            )
        }
    }

    fun onLoadClick(view: View) {
        if (mNativeAdLoader == null) {
            mNativeAdLoader = NativeAdLoader(this, NATIVE_PLACEMENT_ID, this)
        }
        mNativeAdLoader!!.loadAd()
        appendInfo(mTvInfo, "Ad load start ...")
    }


    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            finish()
            return true
        }
        return super.onOptionsItemSelected(item)
    }

    override fun onAdReady() {
        mFlContainer.removeAllViews()

        val info = mNativeAdLoader?.getNativeAd() ?: return

        val nativeView = layoutInflater.inflate(R.layout.simple_native_layout, null,
            false)
        val tvTitle = nativeView.findViewById<TextView>(R.id.tv_title)
        tvTitle.text = info.title

        val tvDesc = nativeView.findViewById<TextView>(R.id.tv_desc)
        tvDesc.text = info.desc

        val btnCta = nativeView.findViewById<Button>(R.id.btn_cta)
        btnCta.text = info.callToActionText


        val iconView = nativeView.findViewById<AdIconView>(R.id.mint_icon_view)


        val mediaView = nativeView.findViewById<MediaView>(R.id.mint_media_view)
        val displayMetrics = resources.displayMetrics
        mediaView.layoutParams.height = (displayMetrics.widthPixels / (1200.0 / 627.0)).toInt()
        mediaView.imageScaleType = ImageView.ScaleType.CENTER_INSIDE

        val advertiser = nativeView.findViewById<TextView>(R.id.tv_ad)


        val mintAdView = NativeAdView(this)
        mintAdView.addView(nativeView)
        mintAdView.titleView = tvTitle
        mintAdView.descView = tvDesc
        mintAdView.adIconView = iconView
        mintAdView.callToActionView = btnCta
        mintAdView.mediaView = mediaView
        mintAdView.advertiserView = advertiser

        // only for yandex
        val domainView = nativeView.findViewById<TextView>(R.id.ad_yandex_domain_view)
        val priceView = nativeView.findViewById<TextView>(R.id.ad_yandex_price_view)
        val sponsoredView = nativeView.findViewById<TextView>(R.id.ad_yandex_sponsored_view)
        val warningView = nativeView.findViewById<TextView>(R.id.ad_yandex_warning_view)
        val feedbackView = nativeView.findViewById<ImageView>(R.id.ad_yandex_feedback_view)
        mintAdView.domainView = domainView
        mintAdView.priceView = priceView
        mintAdView.sponsoredView = sponsoredView
        mintAdView.warningView = warningView
        mintAdView.feedbackView = feedbackView

        info.registerNativeAdView(mintAdView)


        val layoutParams = FrameLayout.LayoutParams(FrameLayout.LayoutParams.WRAP_CONTENT,
            FrameLayout.LayoutParams.WRAP_CONTENT)
        mFlContainer.addView(mintAdView, layoutParams)

        appendInfo(mTvInfo, "Ad impression")

        mNativeAd = info
    }

    override fun onAdFailed(p0: String?) {
        appendInfo(mTvInfo, "Ad failed")
        appendInfo(mTvInfo, "$p0")
    }

    override fun onAdClicked() {
        appendInfo(mTvInfo, "Ad click")
    }

    override fun onDestroy() {
        mNativeAd?.destroy()
        mNativeAdLoader?.destroy()
        super.onDestroy()
    }

}