package com.mint.mintdemo.basic

import android.os.Bundle
import android.text.method.ScrollingMovementMethod
import android.view.MenuItem
import android.view.View
import android.widget.Button
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import com.mint.mintdemo.R
import com.mint.mintdemo.appendInfo
import com.zeus.gmc.sdk.mobileads.mintmediation.interstitial.RewardedInterstitialAd
import com.zeus.gmc.sdk.mobileads.mintmediation.interstitial.RewardedInterstitialListener
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.error.Error
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.model.Scene

class BasicRewardedInterstitialActivity : AppCompatActivity(), RewardedInterstitialListener {

    private lateinit var mTvInfo: TextView
    private lateinit var mBtnShow: Button
    private lateinit var mBtnLoad: Button

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_basic_rewarded_interstitial)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = getString(R.string.rewardedinterstitial)

        mTvInfo = findViewById(R.id.tv_info)
        mBtnShow = findViewById(R.id.btn_show)
        mBtnLoad = findViewById(R.id.btn_load)

        mTvInfo.movementMethod = ScrollingMovementMethod()

        RewardedInterstitialAd.setAdListener(this)

        val adAvailable = RewardedInterstitialAd.isReady()

        mBtnShow.isEnabled = adAvailable
        if (adAvailable) {
            appendInfo(mTvInfo, "Ad available, click show button to show ad")
        } else {
            appendInfo(mTvInfo, "Ad not available, click load button to load ad")
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        RewardedInterstitialAd.destroy()
    }


    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            finish()
            return true
        }
        return super.onOptionsItemSelected(item)
    }


    fun onLoadClick(view: View) {
        appendInfo(mTvInfo, "Ad load start ...")
        if (RewardedInterstitialAd.isReady()) {
            // Ad is ready, cancel load
            appendInfo(mTvInfo, "Ad Ready")
            return
        }
        RewardedInterstitialAd.loadAd()
    }

    fun onShowClick(view: View) {
        /* Optional:
         * Call enterAdScene wherever your application need show Ad,
         * will help you analyse Ad fill rate at mint mediation dashboard.
         *
         * params: placementId, sceneId
         */
        RewardedInterstitialAd.enterAdScene(null, null)

        if (RewardedInterstitialAd.isReady()) {
            RewardedInterstitialAd.showAd()
        }
    }

    override fun onRewardedInterstitialAdAvailabilityChanged(ready: Boolean) {
        appendInfo(mTvInfo, "Ready changed $ready")
        if (ready) {
            appendInfo(mTvInfo, "click show button to show ad")
        }
        mBtnShow.isEnabled = ready
    }

    override fun onRewardedInterstitialAdShowed(scene: Scene?) {
        appendInfo(mTvInfo, "Ad impression")
    }

    override fun onRewardedInterstitialAdShowFailed(scene: Scene?, error: Error?) {
        appendInfo(mTvInfo, "Ad show failed")
    }

    override fun onRewardedInterstitialAdClosed(scene: Scene?) {
        appendInfo(mTvInfo, "Ad show close")
    }

    override fun onRewardedInterstitialAdClicked(scene: Scene?) {
        appendInfo(mTvInfo, "Ad click")
    }

    override fun onRewardedInterstitialAdRewarded(scene: Scene?) {
        appendInfo(mTvInfo, "Ad reward")
    }
}