package com.mint.mintdemo.basic

import android.os.Bundle
import android.text.method.ScrollingMovementMethod
import android.view.MenuItem
import android.view.View
import android.widget.Button
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import com.mint.mintdemo.MainActivity
import com.mint.mintdemo.R
import com.mint.mintdemo.appendInfo
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.error.Error
import com.zeus.gmc.sdk.mobileads.mintmediation.utils.model.Scene
import com.zeus.gmc.sdk.mobileads.mintmediation.video.RewardedVideoAd
import com.zeus.gmc.sdk.mobileads.mintmediation.video.RewardedVideoListener

class BasicRewardedVideoActivity : AppCompatActivity(), RewardedVideoListener {

    private lateinit var mTvInfo: TextView
    private lateinit var mBtnShow: Button
    private lateinit var mBtnLoad: Button

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_basic_rewarded_video)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = getString(R.string.rewardedvideo)

        mTvInfo = findViewById(R.id.tv_info)
        mBtnShow = findViewById(R.id.btn_show)
        mBtnLoad = findViewById(R.id.btn_load)

        mTvInfo.movementMethod = ScrollingMovementMethod()

        RewardedVideoAd.setAdListener(this)

        val adAvailable = RewardedVideoAd.isReady()

        mBtnShow.isEnabled = adAvailable
        if (adAvailable) {
            appendInfo(mTvInfo, "Ad available, click show button to show ad")
        } else {
            appendInfo(mTvInfo, "Ad not available, click load button to load ad")
        }
    }

    override fun onDestroy() {
        super.onDestroy()
        RewardedVideoAd.destroy()
    }


    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            finish()
            return true
        }
        return super.onOptionsItemSelected(item)
    }


    fun onLoadClick(view: View) {
        appendInfo(mTvInfo, "Ad load start ...")
        if (RewardedVideoAd.isReady()) {
            // Ad is ready, cancel load
            appendInfo(mTvInfo, "Ad Ready")
            return
        }
        RewardedVideoAd.loadAd()
    }

    fun onShowClick(view: View) {
        /* Optional:
         * Call enterAdScene wherever your application need show Ad,
         * will help you analyse Ad fill rate at mint mediation dashboard.
         *
         * params: placementId, sceneId
         */
        RewardedVideoAd.enterAdScene(null, null)

        if (RewardedVideoAd.isReady()) {
            RewardedVideoAd.showAd()
        }
    }


    override fun onRewardedVideoAvailabilityChanged(ready: Boolean) {
        appendInfo(mTvInfo, "Ready changed $ready")
        if (ready) {
            appendInfo(mTvInfo, "click show button to show ad")
        }
        mBtnShow.isEnabled = ready
    }

    override fun onRewardedVideoAdShowed(p0: Scene?) {
        appendInfo(mTvInfo, "Ad impression")
    }

    override fun onRewardedVideoAdShowFailed(p0: Scene?, p1: Error?) {
        appendInfo(mTvInfo, "Ad show failed")
    }

    override fun onRewardedVideoAdClicked(p0: Scene?) {
        appendInfo(mTvInfo, "Ad click")
    }

    override fun onRewardedVideoAdClosed(p0: Scene?) {
        appendInfo(mTvInfo, "Ad show close")
    }

    override fun onRewardedVideoAdStarted(p0: Scene?) {
        appendInfo(mTvInfo, "Ad start")
    }

    override fun onRewardedVideoAdEnded(p0: Scene?) {
        appendInfo(mTvInfo, "Ad end")
    }

    override fun onRewardedVideoAdRewarded(p0: Scene?) {
        appendInfo(mTvInfo, "Ad reward")
    }
}