package com.mint.mintdemo.basic

import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.text.method.ScrollingMovementMethod
import android.view.MenuItem
import android.view.View
import android.widget.Button
import android.widget.FrameLayout
import android.widget.TextView
import com.mint.mintdemo.R
import com.mint.mintdemo.appendInfo
import com.zeus.gmc.sdk.mobileads.mintmediation.splash.SplashAd
import com.zeus.gmc.sdk.mobileads.mintmediation.splash.SplashAdListener

class BasicSplashActivity : AppCompatActivity(), SplashAdListener {

    private lateinit var mTvInfo: TextView
    private lateinit var mBtnShow: Button
    private lateinit var mBtnLoad: Button
    private lateinit var mFlContainer: FrameLayout

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.activity_basic_splash)

        supportActionBar?.setDisplayHomeAsUpEnabled(true)
        supportActionBar?.title = getString(R.string.splash)

        mTvInfo = findViewById(R.id.tv_info)
        mBtnShow = findViewById(R.id.btn_show)
        mBtnLoad = findViewById(R.id.btn_load)
        mFlContainer = findViewById(R.id.fl_container)

        mTvInfo.movementMethod = ScrollingMovementMethod()

        mBtnShow.isEnabled = false
        SplashAd.setSplashAdListener(this)
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean {
        if (item.itemId == android.R.id.home) {
            finish()
            return true
        }
        return super.onOptionsItemSelected(item)
    }


    fun onLoadClick(view: View) {
        SplashAd.loadAd()
        appendInfo(mTvInfo, "Ad load start ... ")
    }

    fun onShowClick(view: View) {
        mBtnShow.isEnabled = false
        mFlContainer.visibility = View.VISIBLE
        SplashAd.showAd(this, mFlContainer)
    }

    override fun onSplashAdLoad() {
        mBtnShow.isEnabled = true
        appendInfo(mTvInfo, "Ad load success")
    }

    override fun onSplashAdFailed(p0: String?) {
        appendInfo(mTvInfo, "Ad load failed")
    }

    override fun onSplashAdClicked(scene: String?) {
        appendInfo(mTvInfo, "Ad click")
    }

    override fun onSplashAdShowed(scene: String?) {
        mBtnShow.isEnabled = false
        appendInfo(mTvInfo, "Ad show")
    }

    override fun onSplashAdShowFailed(scene: String?, error: String?) {
        appendInfo(mTvInfo, "Ad show failed")
    }

    override fun onSplashAdTick(p0: Long) {
        appendInfo(mTvInfo, "Ad tick $p0")
    }

    override fun onSplashAdDismissed(scene: String) {
        mFlContainer.removeAllViews()
        mFlContainer.visibility = View.GONE
        appendInfo(mTvInfo, "Ad dismiss")
    }
}