package com.mint.mintdemo.utils.pull_to_refresh

typealias PageDataCallback<T> = (data: List<T>) -> Unit

abstract class BasePullToRefreshDataLoader<T>():
    PullToRefreshDataLoader<T> {

    private var mState = STATE_IDLE

    private val mTotalData = ArrayList<T>()

    private var mPageNo = 1

    override fun onRefresh(controller: PullToRefreshViewController<T>): Boolean {
        if (mState != STATE_IDLE) {
            return false
        }
        mState = STATE_REFRESH
        mPageNo = 1
        loadData (mPageNo) {
            mTotalData.clear()
            mTotalData.addAll(it)
            mState = STATE_IDLE
            controller.onRefreshFinish(mTotalData)
        }
        return true
    }

    override fun onLoadMore(controller: PullToRefreshViewController<T>): Boolean {
        if (mState != STATE_IDLE) {
            return false
        }
        mState = STATE_LOAD_MORE
        loadData(mPageNo + 1) {
            mTotalData.addAll(it)
            mState = STATE_IDLE
            mPageNo += 1
            controller.onLoadMoreFinish(mTotalData)
        }
        return true
    }

    protected abstract fun loadData(pageNo: Int, callback: PageDataCallback<T>)

}

